@@ -20,12 +20,16 @@
 #include <glib-object.h>
 #include <string.h>
 
+#include "gegl-types.h"
+#include "gegl-buffer-types.h"
+#include "gegl-buffer-private.h"
+#include "gegl-utils.h"
 #include "gegl-tile-handler.h"
 #include "gegl-tile-handler-empty.h"
-#include "gegl-tile-handler-cache.h"
 #include "gegl-tile-backend.h"
 
-G_DEFINE_TYPE (GeglTileHandlerEmpty, gegl_tile_handler_empty, GEGL_TYPE_TILE_HANDLER)
+G_DEFINE_TYPE (GeglTileHandlerEmpty, gegl_tile_handler_empty,
+               GEGL_TYPE_TILE_HANDLER)
 
 static void
 finalize (GObject *object)
@@ -38,6 +42,45 @@ finalize (GObject *object)
   G_OBJECT_CLASS (gegl_tile_handler_empty_parent_class)->finalize (object);
 }
 
+static GeglTile *
+_new_empty_tile (const gint tile_size)
+{
+  static GeglTile   *common_tile = NULL;
+  static const gint  common_empty_size = sizeof (gdouble) * 4 * 128 * 128;
+
+  GeglTile *tile;
+
+  if (tile_size > common_empty_size)
+    {
+      /* The tile size is too big to use the shared buffer */
+      tile = gegl_tile_new (tile_size);
+
+      memset (gegl_tile_get_data (tile), 0x00, tile_size);
+      tile->is_zero_tile = 1;
+    }
+  else
+    {
+      if (!common_tile && g_once_init_enter (&common_tile))
+        {
+          GeglTile *allocated_tile = gegl_tile_new_bare ();
+          guchar *allocated_buffer = gegl_malloc (common_empty_size);
+          memset (allocated_buffer, 0x00, common_empty_size);
+
+          allocated_tile->data           = allocated_buffer;
+          allocated_tile->destroy_notify = NULL;
+          allocated_tile->size           = common_empty_size;
+          allocated_tile->is_zero_tile   = 1;
+
+          g_once_init_leave (&common_tile, allocated_tile);
+        }
+
+      tile = gegl_tile_dup (common_tile);
+
+      tile->size = tile_size;
+    }
+
+  return tile;
+}
 
 static GeglTile *
 get_tile (GeglTileSource *gegl_tile_source,
@@ -45,24 +88,23 @@ get_tile (GeglTileSource *gegl_tile_source,
           gint            y,
           gint            z)
 {
-  GeglTileSource       *source = GEGL_TILE_HANDLER (gegl_tile_source)->source;
-  GeglTileHandlerEmpty *empty  = GEGL_TILE_HANDLER_EMPTY (gegl_tile_source);
+  GeglTileSource       *source = ((GeglTileHandler *) gegl_tile_source)->source;
+  GeglTileHandlerEmpty *empty  = (GeglTileHandlerEmpty *) gegl_tile_source;
   GeglTile             *tile   = NULL;
 
   if (source)
     tile = gegl_tile_source_get_tile (source, x, y, z);
-  if (tile != NULL)
+  if (tile)
     return tile;
 
-  tile = gegl_tile_dup (empty->tile);
-  tile->x = x;
-  tile->y = y;
-  tile->z = z;
+  if (!empty->tile)
+    {
+      gint tile_size = gegl_tile_backend_get_tile_size (empty->backend);
+      empty->tile    = _new_empty_tile (tile_size);
+    }
 
-  if (empty->cache)
-    gegl_tile_handler_cache_insert (empty->cache, tile, x, y, z);
-
-  return tile;
+  return gegl_tile_handler_dup_tile (GEGL_TILE_HANDLER (empty),
+                                     empty->tile, x, y, z);
 }
 
 static gpointer
@@ -75,6 +117,7 @@ gegl_tile_handler_empty_command (GeglTileSource  *buffer,
 {
   if (command == GEGL_TILE_GET)
     return get_tile (buffer, x, y, z);
+
   return gegl_tile_handler_source_command (buffer, command, x, y, z, data);
 }
 
@@ -82,23 +125,23 @@ static void
 gegl_tile_handler_empty_class_init (GeglTileHandlerEmptyClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
-  gobject_class->finalize     = finalize;
+
+  gobject_class->finalize = finalize;
 }
 
 static void
 gegl_tile_handler_empty_init (GeglTileHandlerEmpty *self)
 {
-  ((GeglTileSource*)self)->command = gegl_tile_handler_empty_command;
+  ((GeglTileSource *) self)->command = gegl_tile_handler_empty_command;
 }
 
 GeglTileHandler *
-gegl_tile_handler_empty_new (GeglTileBackend      *backend,
-                             GeglTileHandlerCache *cache)
+gegl_tile_handler_empty_new (GeglTileBackend *backend)
 {
   GeglTileHandlerEmpty *empty = g_object_new (GEGL_TYPE_TILE_HANDLER_EMPTY, NULL);
+
   empty->backend = backend;
-  empty->cache = cache;
-  empty->tile = gegl_tile_new (backend->tile_size);
-  memset (gegl_tile_get_data (empty->tile), 0x00, backend->tile_size);
+  empty->tile    = NULL;
+
   return (void*)empty;
 }
