@@ -34,23 +34,20 @@
 #define GEGL_IS_TILE_STORAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GEGL_TYPE_TILE_STORAGE))
 #define GEGL_TILE_STORAGE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GEGL_TYPE_TILE_STORAGE, GeglTileStorageClass))
 
+typedef struct _GeglTileStorageClass GeglTileStorageClass;
+
 struct _GeglTileStorage
 {
   GeglTileHandlerChain parent_instance;
   GeglTileHandlerCache *cache;
-  GMutex        *mutex;
+  GRecMutex      mutex;
   const Babl    *format;
   gint           tile_width;
   gint           tile_height;
   gint           tile_size;
   gint           px_size;
-  gint           width;
-  gint           height;
-  gchar         *path;
   gint           seen_zoom; /* the maximum zoom level we've seen tiles for */
 
-  guint          idle_swapper;
-
   GeglTile      *hot_tile; /* cached tile for speeding up gegl_buffer_get_pixel
                               and gegl_buffer_set_pixel (1x1 sized gets/sets)*/
 };
@@ -65,4 +62,7 @@ GType gegl_tile_storage_get_type (void) G_GNUC_CONST;
 GeglTileStorage *
 gegl_tile_storage_new (GeglTileBackend *backend);
 
+void gegl_tile_storage_add_handler (GeglTileStorage *tile_storage, GeglTileHandler *handler);
+void gegl_tile_storage_remove_handler (GeglTileStorage *tile_storage, GeglTileHandler *handler);
+
 #endif
