@@ -310,7 +310,13 @@ gegl_operation_prepare (GeglOperation *self)
   g_return_if_fail (GEGL_IS_OPERATION (self));
 
   if (self->node->passthrough)
-    return;
+    {
+      const Babl *format;
+
+      format = gegl_operation_get_source_format (self, "input");
+      gegl_operation_set_format (self, "output", format);
+      return;
+    }
 
   klass = GEGL_OPERATION_GET_CLASS (self);
 
@@ -514,15 +520,10 @@ gegl_operation_invalidate (GeglOperation       *operation,
                            const GeglRectangle *roi,
                            gboolean             clear_cache)
 {
-  GeglNode *node = NULL;
-
-  if (!operation)
-    return;
-
   g_return_if_fail (GEGL_IS_OPERATION (operation));
-  node = operation->node;
 
-  gegl_node_invalidated (node, roi, clear_cache);
+  if (operation->node)
+    gegl_node_invalidated (operation->node, roi, clear_cache);
 }
 
 gboolean
@@ -828,3 +829,11 @@ void gegl_temp_buffer_free (void)
       gegl_temp_size[no] = 0;
     }
 }
+
+void gegl_operation_progress (GeglOperation *operation,
+                              gdouble        progress,
+                              gchar         *message)
+{
+  if (operation->node)
+    gegl_node_progress (operation->node, progress, message);
+}
