@@ -36,6 +36,8 @@ static const char* op_c_source =
 "                                                                              \n"
 "property_double (refraction_index, _(\"Lens refraction index\"), 1.7)         \n"
 "  value_range (1.0, 100.0)                                                    \n"
+"  ui_range    (1.0, 10.0)                                                     \n"
+"  ui_gamma    (3.0)                                                           \n"
 "                                                                              \n"
 "property_boolean (keep_surroundings, _(\"Keep original surroundings\"), FALSE)\n"
 "  description(_(\"Keep image unchanged, where not affected by the lens.\"))   \n"
