@@ -147,7 +147,7 @@ gegl_op_class_init (GeglOpClass *klass)
 
   gegl_operation_class_set_keys (operation_class,
       "name",       "gegl:brightness-contrast",
-      "title",      "Brightness Contrast",
+      "title",      _("Brightness Contrast"),
       "categories", "color",
       "description", _("Changes the light level and contrast. This operation operates in linear light, 'contrast' is a scale factor around 50%% gray, and 'brightness' a constant offset to apply after contrast scaling."),
       "cl-source"  , brightness_contrast_cl_source,
