@@ -61,7 +61,8 @@ static const char* op_c_source =
 "                                                                              \n"
 "#define RGAMMA 2.0                                                            \n"
 "                                                                              \n"
-"static void c2g (GeglBuffer          *src,                                    \n"
+"static void c2g (GeglOperation       *op,                                     \n"
+"                 GeglBuffer          *src,                                    \n"
 "                 const GeglRectangle *src_rect,                               \n"
 "                 GeglBuffer          *dst,                                    \n"
 "                 const GeglRectangle *dst_rect,                               \n"
@@ -75,10 +76,15 @@ static const char* op_c_source =
 "                                                                              \n"
 "  if (dst_rect->width > 0 && dst_rect->height > 0)                            \n"
 "  {                                                                           \n"
+"    /* XXX: compute total pixels and progress by consumption                  \n"
+"     */                                                                       \n"
 "    GeglBufferIterator *i = gegl_buffer_iterator_new (dst, dst_rect, 0, babl_format(\"YA float\"),\n"
 "                                                      GEGL_ACCESS_WRITE, GEGL_ABYSS_NONE);\n"
 "    GeglSampler *sampler = gegl_buffer_sampler_new_at_level (src, format, GEGL_SAMPLER_NEAREST, level);\n"
 "                                                                              \n"
+"    float total_pix = dst_rect->width * dst_rect->height;                     \n"
+"    int pix_done = 0.0;                                                       \n"
+"                                                                              \n"
 "    while (gegl_buffer_iterator_next (i))                                     \n"
 "    {                                                                         \n"
 "      gint x,y;                                                               \n"
@@ -133,7 +139,12 @@ static const char* op_c_source =
 "                dst_offset+=2;                                                \n"
 "              }                                                               \n"
 "            }                                                                 \n"
+"                                                                              \n"
+"            pix_done += i->roi[0].width;                                      \n"
 "          }                                                                   \n"
+"#if 0                                                                         \n"
+"        gegl_operation_progress (op, pix_done / total_pix, \"\");             \n"
+"#endif                                                                        \n"
 "    }                                                                         \n"
 "    g_object_unref (sampler);                                                 \n"
 "  }                                                                           \n"
@@ -161,7 +172,7 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "#include \"opencl/gegl-cl.h\"                                                 \n"
-"#include \"buffer/gegl-buffer-cl-iterator.h\"                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
 "                                                                              \n"
 "#include \"opencl/c2g.cl.h\"                                                  \n"
 "                                                                              \n"
@@ -328,7 +339,7 @@ static const char* op_c_source =
 "    if(cl_process(operation, input, output, result))                          \n"
 "      return TRUE;                                                            \n"
 "                                                                              \n"
-"  c2g (input, &compute, output, result,                                       \n"
+"  c2g (operation, input, &compute, output, result,                            \n"
 "       o->radius,                                                             \n"
 "       o->samples,                                                            \n"
 "       o->iterations,                                                         \n"
