@@ -69,7 +69,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "#include \"gegl-op.h\"                                                        \n"
 "#include <gegl-buffer-cl-iterator.h>                                          \n"
-"#include <gegl-debug.h>                                                       \n"
+"#include <../../gegl/gegl-debug.h>                                            \n"
 "                                                                              \n"
 "static void                                                                   \n"
 "prepare (GeglOperation *operation)                                            \n"
