@@ -147,12 +147,13 @@ static const char* op_c_source =
 "                                                                              \n"
 "                                                                              \n"
 "static void                                                                   \n"
-"binary_dt_2nd_pass (gint          width,                                      \n"
-"                    gint          height,                                     \n"
-"                    gfloat        thres_lo,                                   \n"
-"                    GeglDTMetric  metric,                                     \n"
-"                    gfloat       *src,                                        \n"
-"                    gfloat       *dest)                                       \n"
+"binary_dt_2nd_pass (GeglOperation *operation,                                 \n"
+"                    gint           width,                                     \n"
+"                    gint           height,                                    \n"
+"                    gfloat         thres_lo,                                  \n"
+"                    GeglDTMetric   metric,                                    \n"
+"                    gfloat        *src,                                       \n"
+"                    gfloat        *dest)                                      \n"
 "{                                                                             \n"
 "  gint u, y;                                                                  \n"
 "  gint q, w, *t, *s;                                                          \n"
@@ -236,6 +237,9 @@ static const char* op_c_source =
 "              q--;                                                            \n"
 "            }                                                                 \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"      gegl_operation_progress (operation,                                     \n"
+"                               (gdouble) y / (gdouble) height / 2.0 + 0.5, \"\");\n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  gegl_free (t);                                                              \n"
@@ -245,11 +249,12 @@ static const char* op_c_source =
 "                                                                              \n"
 "                                                                              \n"
 "static void                                                                   \n"
-"binary_dt_1st_pass (gint    width,                                            \n"
-"                    gint    height,                                           \n"
-"                    gfloat  thres_lo,                                         \n"
-"                    gfloat *src,                                              \n"
-"                    gfloat *dest)                                             \n"
+"binary_dt_1st_pass (GeglOperation *operation,                                 \n"
+"                    gint           width,                                     \n"
+"                    gint           height,                                    \n"
+"                    gfloat         thres_lo,                                  \n"
+"                    gfloat        *src,                                       \n"
+"                    gfloat        *dest)                                      \n"
 "{                                                                             \n"
 "  int x, y;                                                                   \n"
 "                                                                              \n"
@@ -273,6 +278,9 @@ static const char* op_c_source =
 "          if (dest[x + (y + 1) * width] + 1.0 < dest[x + y * width])          \n"
 "            dest [x + y * width] = dest[x + (y + 1) * width] + 1.0;           \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"      gegl_operation_progress (operation,                                     \n"
+"                               (gdouble) x / (gdouble) width / 2.0, \"\");    \n"
 "    }                                                                         \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -314,14 +322,16 @@ static const char* op_c_source =
 "  src_buf = gegl_malloc (width * height * bytes_per_pixel);                   \n"
 "  dst_buf = gegl_calloc (width * height, bytes_per_pixel);                    \n"
 "                                                                              \n"
+"  gegl_operation_progress (operation, 0.0, \"\");                             \n"
+"                                                                              \n"
 "  gegl_buffer_get (input, result, 1.0, input_format, src_buf,                 \n"
 "                   GEGL_AUTO_ROWSTRIDE, GEGL_ABYSS_NONE);                     \n"
 "                                                                              \n"
 "  if (!averaging)                                                             \n"
 "    {                                                                         \n"
-"      binary_dt_1st_pass (width, height, threshold_lo,                        \n"
+"      binary_dt_1st_pass (operation, width, height, threshold_lo,             \n"
 "                          src_buf, dst_buf);                                  \n"
-"      binary_dt_2nd_pass (width, height, threshold_lo, metric,                \n"
+"      binary_dt_2nd_pass (operation, width, height, threshold_lo, metric,     \n"
 "                          src_buf, dst_buf);                                  \n"
 "    }                                                                         \n"
 "  else                                                                        \n"
@@ -338,9 +348,9 @@ static const char* op_c_source =
 "          thres = (i+1) * (threshold_hi - threshold_lo) / (averaging + 1);    \n"
 "          thres += threshold_lo;                                              \n"
 "                                                                              \n"
-"          binary_dt_1st_pass (width, height, thres,                           \n"
+"          binary_dt_1st_pass (operation, width, height, thres,                \n"
 "                              src_buf, tmp_buf);                              \n"
-"          binary_dt_2nd_pass (width, height, thres, metric,                   \n"
+"          binary_dt_2nd_pass (operation, width, height, thres, metric,        \n"
 "                              src_buf, tmp_buf);                              \n"
 "                                                                              \n"
 "          for (j = 0; j < width * height; j++)                                \n"
@@ -371,6 +381,8 @@ static const char* op_c_source =
 "  gegl_buffer_set (output, result, 0, input_format, dst_buf,                  \n"
 "                   GEGL_AUTO_ROWSTRIDE);                                      \n"
 "                                                                              \n"
+"  gegl_operation_progress (operation, 1.0, \"\");                             \n"
+"                                                                              \n"
 "  gegl_free (dst_buf);                                                        \n"
 "  gegl_free (src_buf);                                                        \n"
 "                                                                              \n"
