@@ -270,7 +270,7 @@ edge_laplace (GeglBuffer          *src,
 }
 
 #include "opencl/gegl-cl.h"
-#include "buffer/gegl-buffer-cl-iterator.h"
+#include "gegl-buffer-cl-iterator.h"
 
 #include "opencl/edge-laplace.cl.h"
 
