@@ -79,7 +79,7 @@ static const char* op_c_source =
 "/*                                                                            \n"
 "                                                                              \n"
 "#include \"opencl/gegl-cl.h\"                                                 \n"
-"#include \"buffer/gegl-buffer-cl-iterator.h\"                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
 "                                                                              \n"
 "#include \"opencl/edge-sobel.cl.h\"                                           \n"
 "                                                                              \n"
