@@ -205,7 +205,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  format = babl_format (\"RGBA float\");                                      \n"
 "  dst_buf = g_new0 (gfloat, result->width * result->height * 4);              \n"
-"  sampler = gegl_buffer_sampler_new_at_level (input, format, GEGL_SAMPLER_NOHALO, level);\n"
+"  sampler = gegl_buffer_sampler_new_at_level (input, format, GEGL_SAMPLER_CUBIC, level);\n"
 "                                                                              \n"
 "  for (y = result->y; y < result->y + result->height; y++)                    \n"
 "    fractaltrace (input, sampler, &boundary, dst_buf, result, o, y, o->fractal, format, level);\n"
