@@ -379,7 +379,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "                                                                              \n"
 "#include \"opencl/gegl-cl.h\"                                                 \n"
-"#include \"buffer/gegl-buffer-cl-iterator.h\"                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
 "                                                                              \n"
 "#include \"opencl/gblur-1d.cl.h\"                                             \n"
 "                                                                              \n"
