@@ -90,7 +90,8 @@ static const char* op_c_source =
 "    \"description\", _(\"GeglBuffer file loader.\"),                          \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".gegl\", \"gegl:gegl-buffer-load\");\n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".gegl\", \"gegl:gegl-buffer-load\");                                    \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
