@@ -51,6 +51,7 @@ static const char* op_c_source =
 "static void prepare (GeglOperation *operation)                                \n"
 "{                                                                             \n"
 "  const Babl *format = gegl_operation_get_source_format (operation, \"input\");\n"
+"  const GeglRectangle *bb = gegl_operation_source_get_bounding_box (operation, \"input\");\n"
 "                                                                              \n"
 "  if (! format || ! babl_format_has_alpha (format))                           \n"
 "    format = babl_format (\"R'G'B' float\");                                  \n"
@@ -59,6 +60,28 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_set_format (operation, \"input\",  format);                  \n"
 "  gegl_operation_set_format (operation, \"output\", format);                  \n"
+"                                                                              \n"
+"  if (bb && ! gegl_rectangle_is_infinite_plane (bb))                          \n"
+"    {                                                                         \n"
+"      GeglProperties *o  = GEGL_PROPERTIES (operation);                       \n"
+"      gdouble        *dx = g_new (gdouble, (4 * o->division + 1) * 2);        \n"
+"      gdouble        *dy = &dx[4 * o->division + 1];                          \n"
+"      gdouble         offset = (gint) (sqrt (bb->width * bb->width + bb->height * bb->height) / 4);\n"
+"      gint            i;                                                      \n"
+"                                                                              \n"
+"      g_object_set_data_full (G_OBJECT (operation), \"free-me\",              \n"
+"                              o->user_data = dx, g_free);                     \n"
+"                                                                              \n"
+"      for (i = -2 * o->division; i <= 2 * o->division; ++i)                   \n"
+"        {                                                                     \n"
+"          gdouble a = G_PI / o->division * (i * 0.5 + 1.0);                   \n"
+"          gdouble c = cos (a);                                                \n"
+"          gdouble s = sin (a);                                                \n"
+"                                                                              \n"
+"          dx[i + 2 * o->division] = GEGL_FLOAT_IS_ZERO (c) ? 0.0 : c * offset;\n"
+"          dy[i + 2 * o->division] = GEGL_FLOAT_IS_ZERO (s) ? 0.0 : s * offset;\n"
+"        }                                                                     \n"
+"    }                                                                         \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static GeglRectangle                                                          \n"
@@ -99,16 +122,17 @@ static const char* op_c_source =
 "  GeglSampler        *sampler;                                                \n"
 "                                                                              \n"
 "  gint         x, y, xx, yy, b;                                               \n"
-"  gint         width, height, components;                                     \n"
-"  gdouble      radius, cx, cy, angle;                                         \n"
+"  gint         width, height, components, angle;                              \n"
+"  gdouble      radius, cx, cy;                                                \n"
 "  gdouble      center_x;                                                      \n"
 "  gdouble      center_y;                                                      \n"
 "  gdouble      scale;                                                         \n"
-"  gdouble      offset;                                                        \n"
 "  gboolean     has_alpha;                                                     \n"
 "  gfloat       alpha, alpha1, alpha2;                                         \n"
 "  gfloat      *in_pixel1;                                                     \n"
 "  gfloat      *in_pixel2;                                                     \n"
+"  const gdouble *dx = o->user_data;                                           \n"
+"  const gdouble *dy = &dx[4 * o->division + 1];                               \n"
 "                                                                              \n"
 "  const Babl *format = gegl_operation_get_format (operation, \"output\");     \n"
 "  has_alpha  = babl_format_has_alpha (format);                                \n"
@@ -133,7 +157,6 @@ static const char* op_c_source =
 "  center_x = width / 2.0;                                                     \n"
 "  center_y = height / 2.0;                                                    \n"
 "  scale = sqrt (width * width + height * height) / 2;                         \n"
-"  offset = (gint) (scale / 2);                                                \n"
 "                                                                              \n"
 "  while (gegl_buffer_iterator_next (iter))                                    \n"
 "    {                                                                         \n"
@@ -145,19 +168,19 @@ static const char* op_c_source =
 "              cy = ((gdouble) y - center_y) / scale;                          \n"
 "              cx = ((gdouble) x - center_x) / scale;                          \n"
 "                                                                              \n"
-"              angle = floor (atan2 (cy, cx) * o->division / G_PI_2) *         \n"
-"                             G_PI_2 / o->division + (G_PI / o->division);     \n"
+"              angle = floor (atan2 (cy, cx) * o->division / G_PI_2 +          \n"
+"                             GEGL_FLOAT_EPSILON);                             \n"
 "              radius = sqrt ((gdouble) (cx * cx + cy * cy));                  \n"
 "                                                                              \n"
 "              if (o->illusion_type == GEGL_ILLUSION_TYPE_1)                   \n"
 "                {                                                             \n"
-"                   xx = x - offset * cos (angle);                             \n"
-"                   yy = y - offset * sin (angle);                             \n"
+"                   xx = x - dx [2 * o->division + angle];                     \n"
+"                   yy = y - dy [2 * o->division + angle];                     \n"
 "                }                                                             \n"
 "              else                          /* GEGL_ILLUSION_TYPE_2 */        \n"
 "                {                                                             \n"
-"                   xx = x - offset * sin (angle);                             \n"
-"                   yy = y - offset * cos (angle);                             \n"
+"                   xx = x - dy [2 * o->division + angle];                     \n"
+"                   yy = y - dx [2 * o->division + angle];                     \n"
 "                }                                                             \n"
 "                                                                              \n"
 "                gegl_sampler_get (sampler, x, y, NULL,                        \n"
