@@ -154,7 +154,7 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "#include \"opencl/gegl-cl.h\"                                                 \n"
-"#include \"buffer/gegl-buffer-cl-iterator.h\"                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
 "                                                                              \n"
 "#include \"opencl/noise-reduction.cl.h\"                                      \n"
 "                                                                              \n"
