@@ -385,7 +385,7 @@ pixelize (gfloat              *input,
 }
 
 #include "opencl/gegl-cl.h"
-#include "buffer/gegl-buffer-cl-iterator.h"
+#include "gegl-buffer-cl-iterator.h"
 
 #include "opencl/pixelize.cl.h"
 
