@@ -271,7 +271,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "  gegl_operation_class_set_keys (operation_class,                             \n"
 "  \"name\",      \"gegl:reinhard05\",                                         \n"
-"  \"title\",      _(\"Reinhard 2005 Tonemapper\"),                            \n"
+"  \"title\",      _(\"Reinhard 2005 Tone Mapping\"),                          \n"
 "  \"categories\" , \"tonemapping\",                                           \n"
 "  \"description\",                                                            \n"
 "        _(\"Adapt an image, which may have a high dynamic range, for \"       \n"
