@@ -73,7 +73,7 @@ gegl_save_set_saver (GeglOperation *operation)
    */
   g_assert (o->path);
   extension = strrchr (o->path, '.');
-  handler   = extension ? gegl_extension_handler_get_saver (extension) : NULL;
+  handler   = extension ? gegl_operation_handlers_get_saver (extension) : NULL;
 
   if (handler)
     {
