@@ -74,7 +74,7 @@ static const char* op_c_source =
 "   */                                                                         \n"
 "  g_assert (o->path);                                                         \n"
 "  extension = strrchr (o->path, '.');                                         \n"
-"  handler   = extension ? gegl_extension_handler_get_saver (extension) : NULL;\n"
+"  handler   = extension ? gegl_operation_handlers_get_saver (extension) : NULL;\n"
 "                                                                              \n"
 "  if (handler)                                                                \n"
 "    {                                                                         \n"
