@@ -226,7 +226,7 @@ static const char* op_c_source =
 "          \"This improves images that make poor use of the available contrast \"\n"
 "          \"(little contrast, very dark, or very bright images). \"           \n"
 "          \"This version differs from Contrast Autostretch in that it works \"\n"
-"          \"in HSV scpace, and preserves hue.\"),                             \n"
+"          \"in HSV space, and preserves hue.\"),                              \n"
 "        NULL);                                                                \n"
 "}                                                                             \n"
 "                                                                              \n"
