@@ -121,7 +121,7 @@ static const char* op_c_source =
 "}                                                                             \n"
 "                                                                              \n"
 "#include \"opencl/gegl-cl.h\"                                                 \n"
-"#include \"buffer/gegl-buffer-cl-iterator.h\"                                 \n"
+"#include \"gegl-buffer-cl-iterator.h\"                                        \n"
 "#include \"opencl/stretch-contrast.cl.h\"                                     \n"
 "                                                                              \n"
 "static GeglClRunData *cl_data = NULL;                                         \n"
