@@ -22,22 +22,20 @@
 #include <glib/gi18n-lib.h>
 
 
-#ifdef GEGL_CHANT_PROPERTIES
-
-gegl_chant_string (values, _("Values"), "", _("list of <number>s"))
+#ifdef GEGL_PROPERTIES
 
 #else
 
-#define GEGL_CHANT_TYPE_POINT_FILTER
-#define GEGL_CHANT_C_FILE       "svg-luminancetoalpha.c"
+#define GEGL_OP_POINT_FILTER
+#define GEGL_OP_C_SOURCE svg-luminancetoalpha.c
 
-#include "gegl-chant.h"
+#include "gegl-op.h"
 #include <math.h>
 #include <stdlib.h>
 
 static void prepare (GeglOperation *operation)
 {
-  Babl *format = babl_format ("RaGaBaA float");
+  const Babl *format = babl_format ("RaGaBaA float");
 
   gegl_operation_set_format (operation, "input", format);
   gegl_operation_set_format (operation, "output", format);
@@ -48,7 +46,8 @@ process (GeglOperation       *op,
          void                *in_buf,
          void                *out_buf,
          glong                n_pixels,
-         const GeglRectangle *roi)
+         const GeglRectangle *roi,
+         gint                 level)
 {
   gfloat      *in = in_buf;
   gfloat      *out = out_buf;
@@ -76,7 +75,7 @@ process (GeglOperation       *op,
 
 
 static void
-gegl_chant_class_init (GeglChantClass *klass)
+gegl_op_class_init (GeglOpClass *klass)
 {
   GeglOperationClass            *operation_class;
   GeglOperationPointFilterClass *point_filter_class;
@@ -87,10 +86,12 @@ gegl_chant_class_init (GeglChantClass *klass)
   point_filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "gegl:svg-luminancetoalpha";
-  operation_class->categories  = "compositors:svgfilter";
-  operation_class->description =
-        _("SVG color matrix operation svg_luminancetoalpha");
+  gegl_operation_class_set_keys (operation_class,
+    "name"       , "gegl:svg-luminancetoalpha",
+    "categories" , "compositors:svgfilter",
+    "description",
+       _("SVG color matrix operation svg_luminancetoalpha"),
+        NULL);
 }
 
 #endif
