@@ -202,13 +202,16 @@ static const char* op_c_source =
 "  const size_t gbl_size[2] = {roi->width, roi->height};                       \n"
 "  const size_t gbl_off[2]  = {roi->x, roi->y};                                \n"
 "  cl_int cl_err = 0;                                                          \n"
+"  cl_mem filter_pat = NULL;                                                   \n"
 "                                                                              \n"
-"  cl_mem filter_pat = gegl_clCreateBuffer (gegl_cl_get_context (),            \n"
-"                                           CL_MEM_READ_ONLY | CL_MEM_COPY_HOST_PTR,\n"
-"                                           pattern_width[o->pattern] *        \n"
-"                                           pattern_height[o->pattern] * sizeof(cl_int),\n"
-"                                           (void*)pattern[o->pattern],        \n"
-"                                           &cl_err);                          \n"
+"  if (!cl_data)                                                               \n"
+"    goto error;                                                               \n"
+"  filter_pat = gegl_clCreateBuffer (gegl_cl_get_context (),                   \n"
+"                                    CL_MEM_READ_ONLY | CL_MEM_COPY_HOST_PTR,  \n"
+"                                    pattern_width[o->pattern] *               \n"
+"                                    pattern_height[o->pattern] * sizeof(cl_int),\n"
+"                                    (void*)pattern[o->pattern],               \n"
+"                                    &cl_err);                                 \n"
 "  CL_CHECK;                                                                   \n"
 "  cl_err = gegl_cl_set_kernel_args (cl_data->kernel[0],                       \n"
 "                                    sizeof(cl_mem), &in_buf,                  \n"
