@@ -98,9 +98,8 @@ static const char* op_c_source =
 "    if (!name) {                                                              \n"
 "      return NULL;                                                            \n"
 "    }                                                                         \n"
-"    dup = g_strdup(name);                                                     \n"
+"    dup = g_ascii_strdown(name, -1);                                          \n"
 "    replace_char_inline(dup, '/', ':');                                       \n"
-"    g_ascii_strdown(dup, -1);                                                 \n"
 "    return dup;                                                               \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -110,9 +109,8 @@ static const char* op_c_source =
 "    if (!name) {                                                              \n"
 "      return NULL;                                                            \n"
 "    }                                                                         \n"
-"    dup = g_strdup(name);                                                     \n"
+"    dup = g_ascii_strdown(name, -1);                                          \n"
 "    replace_char_inline(dup, '/', '_');                                       \n"
-"    g_ascii_strdown(dup, -1);                                                 \n"
 "    return dup;                                                               \n"
 "}                                                                             \n"
 "                                                                              \n"
@@ -221,8 +219,9 @@ static const char* op_c_source =
 "    if (json_object_has_member(root, \"inports\")) {                          \n"
 "        JsonObject *inports = json_object_get_object_member(root, \"inports\");\n"
 "        GList *inport_names = json_object_get_members(inports);               \n"
-"        for (int i=0; i<g_list_length(inport_names); i++) {                   \n"
-"            const gchar *name = g_list_nth_data(inport_names, i);             \n"
+"        GList *l;                                                             \n"
+"        for (l = inport_names; l != NULL; l = l->next) {                      \n"
+"            const gchar *name = l->data;                                      \n"
 "            JsonObject *conn = json_object_get_object_member(inports, name);  \n"
 "            const gchar *proc = json_object_get_string_member(conn, \"process\");\n"
 "            const gchar *port = json_object_get_string_member(conn, \"port\");\n"
@@ -249,6 +248,8 @@ static const char* op_c_source =
 "              g_free(opname);                                                 \n"
 "            }                                                                 \n"
 "        }                                                                     \n"
+"                                                                              \n"
+"        g_list_free(inport_names);                                            \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "/*                                                                            \n"
@@ -340,14 +341,15 @@ static const char* op_c_source =
 "  JsonOp *self = (JsonOp *)operation;                                         \n"
 "  GeglNode  *gegl = operation->node;                                          \n"
 "  JsonArray *connections;                                                     \n"
+"  GList *l;                                                                   \n"
 "                                                                              \n"
 "  // Processes                                                                \n"
 "  JsonObject *root = self->json_root;                                         \n"
 "  JsonObject *processes = json_object_get_object_member(root, \"processes\"); \n"
 "                                                                              \n"
 "  GList *process_names = json_object_get_members(processes);                  \n"
-"  for (int i=0; i<g_list_length(process_names); i++) {                        \n"
-"      const gchar *name = g_list_nth_data(process_names, i);                  \n"
+"  for (l = process_names; l != NULL; l = l->next) {                           \n"
+"      const gchar *name = l->data;                                            \n"
 "      JsonObject *proc = json_object_get_object_member(processes, name);      \n"
 "      const gchar *component = json_object_get_string_member(proc, \"component\");\n"
 "      gchar *opname = component2geglop(component);                            \n"
@@ -404,8 +406,8 @@ static const char* op_c_source =
 "  if (json_object_has_member(root, \"inports\")) {                            \n"
 "      JsonObject *inports = json_object_get_object_member(root, \"inports\"); \n"
 "      GList *inport_names = json_object_get_members(inports);                 \n"
-"      for (int i=0; i<g_list_length(inport_names); i++) {                     \n"
-"          const gchar *name = g_list_nth_data(inport_names, i);               \n"
+"      for (l = inport_names; l != NULL; l = l->next) {                        \n"
+"          const gchar *name = l->data;                                        \n"
 "          JsonObject *conn = json_object_get_object_member(inports, name);    \n"
 "          const gchar *proc = json_object_get_string_member(conn, \"process\");\n"
 "          const gchar *port = json_object_get_string_member(conn, \"port\");  \n"
@@ -420,13 +422,15 @@ static const char* op_c_source =
 "            gegl_operation_meta_redirect (operation, name, node, port);       \n"
 "          }                                                                   \n"
 "      }                                                                       \n"
+"                                                                              \n"
+"      g_list_free(inport_names);                                              \n"
 "  }                                                                           \n"
 "                                                                              \n"
 "  if (json_object_has_member(root, \"outports\")) {                           \n"
 "      JsonObject *outports = json_object_get_object_member(root, \"outports\");\n"
 "      GList *outport_names = json_object_get_members(outports);               \n"
-"      for (int i=0; i<g_list_length(outport_names); i++) {                    \n"
-"          const gchar *name = g_list_nth_data(outport_names, i);              \n"
+"      for (l = outport_names; l != NULL; l = l->next) {                       \n"
+"          const gchar *name = l->data;                                        \n"
 "          JsonObject *conn = json_object_get_object_member(outports, name);   \n"
 "          const gchar *proc = json_object_get_string_member(conn, \"process\");\n"
 "          const gchar *port = json_object_get_string_member(conn, \"port\");  \n"
@@ -440,6 +444,8 @@ static const char* op_c_source =
 "            g_warning(\"Unsupported output '%s' exported in .json file\", name);\n"
 "          }                                                                   \n"
 "      }                                                                       \n"
+"                                                                              \n"
+"      g_list_free(outport_names);                                             \n"
 "  }                                                                           \n"
 "                                                                              \n"
 "}                                                                             \n"
@@ -504,6 +510,7 @@ static const char* op_c_source =
 "    \"description\",  (description) ? description : \"\",                     \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
+"  g_free(name);                                                               \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void                                                                   \n"
