@@ -684,7 +684,10 @@ gegl_op_class_init (GeglOpClass *klass)
     "categories"  , "hidden",
     "description" , "EXR image loader.", NULL);
 
-  gegl_extension_handler_register_loader (".exr", "gegl:exr-load");
+  gegl_operation_handlers_register_loader (
+    "image/x-exr", "gegl:exr-load");
+  gegl_operation_handlers_register_loader (
+    ".exr", "gegl:exr-load");
 }
 
 #endif
