@@ -421,12 +421,13 @@ static const char* op_c_source =
 "      )                                                                       \n"
 "    {                                                                         \n"
 "      gint i;                                                                 \n"
-"      gchar dereferenced_path[PATH_MAX];                                      \n"
+"      gchar *dereferenced_path;                                               \n"
 "      gint err;                                                               \n"
 "                                                                              \n"
 "      ff_cleanup (o);                                                         \n"
-"      realpath (o->path, dereferenced_path);                                  \n"
+"      dereferenced_path = realpath (o->path, NULL);                           \n"
 "      err = avformat_open_input(&p->video_fcontext, dereferenced_path, NULL, 0);\n"
+"      free (dereferenced_path);                                               \n"
 "      if (err < 0)                                                            \n"
 "        {                                                                     \n"
 "          print_error (o->path, err);                                         \n"
