@@ -687,9 +687,8 @@ static const char* op_c_source =
 "  p->video_outbuf = NULL;                                                     \n"
 "  if (!(oc->oformat->flags & AVFMT_RAWPICTURE))                               \n"
 "    {                                                                         \n"
-"      /* allocate output buffer */                                            \n"
-"      /* XXX: API change will be done */                                      \n"
-"      p->video_outbuf_size = 200000;                                          \n"
+"      /* allocate output buffer, 1 mb / frame, might fail for some codecs on UHD - but works for now */\n"
+"      p->video_outbuf_size = 1024 * 1024;                                     \n"
 "      p->video_outbuf = malloc (p->video_outbuf_size);                        \n"
 "    }                                                                         \n"
 "                                                                              \n"
@@ -727,7 +726,7 @@ static const char* op_c_source =
 "      av_free (p->tmp_picture->data[0]);                                      \n"
 "      av_free (p->tmp_picture);                                               \n"
 "    }                                                                         \n"
-"  av_free (p->video_outbuf);                                                  \n"
+"  free (p->video_outbuf);                                                     \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#include \"string.h\"                                                         \n"
