@@ -89,7 +89,7 @@ static const char* op_c_source =
 "                                 NULL, &error);                               \n"
 "      if (read < 0)                                                           \n"
 "        {                                                                     \n"
-"          g_warning(error->message);                                          \n"
+"          g_warning(\"%s\", error->message);                                  \n"
 "          g_error_free(error);                                                \n"
 "          break;                                                              \n"
 "        }                                                                     \n"
@@ -129,21 +129,21 @@ static const char* op_c_source =
 "      image_fmt = jas_image_getfmt (jasper);                                  \n"
 "      if (image_fmt < 0)                                                      \n"
 "        {                                                                     \n"
-"          g_warning (_(\"Unknown JPEG 2000 image format\"));                  \n"
+"          g_warning (\"%s\", _(\"Unknown JPEG 2000 image format\"));          \n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
 "      image = jas_image_decode (jasper, image_fmt, NULL);                     \n"
 "      if (!image)                                                             \n"
 "        {                                                                     \n"
-"          g_warning (_(\"Unable to open JPEG 2000 image\"));                  \n"
+"          g_warning (\"%s\", _(\"Unable to open JPEG 2000 image\"));          \n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
 "      output_profile = jas_cmprof_createfromclrspc (JAS_CLRSPC_SRGB);         \n"
 "      if (!output_profile)                                                    \n"
 "        {                                                                     \n"
-"          g_warning (_(\"Unable to create output color profile\"));           \n"
+"          g_warning (\"%s\", _(\"Unable to create output color profile\"));   \n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
@@ -151,7 +151,7 @@ static const char* op_c_source =
 "                                     JAS_CMXFORM_INTENT_PER);                 \n"
 "      if (!p->image)                                                          \n"
 "        {                                                                     \n"
-"          g_warning (_(\"Unable to convert image to sRGB color space\"));     \n"
+"          g_warning (\"%s\", _(\"Unable to convert image to sRGB color space\"));\n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
@@ -196,7 +196,7 @@ static const char* op_c_source =
 "              (jas_image_cmptwidth (p->image, i) != p->width) ||              \n"
 "              (jas_image_cmptheight (p->image, i) != p->height))              \n"
 "            {                                                                 \n"
-"              g_warning (_(\"Components of JPEG 2000 input don't match\"));   \n"
+"              g_warning (\"%s\", _(\"Components of JPEG 2000 input don't match\"));\n"
 "              b = TRUE;                                                       \n"
 "              break;                                                          \n"
 "            }                                                                 \n"
@@ -258,7 +258,7 @@ static const char* op_c_source =
 "      jasper = jas_stream_memopen(NULL, -1);                                  \n"
 "      if (jasper == NULL)                                                     \n"
 "        {                                                                     \n"
-"          g_warning(_(\"could not create a new Jasper stream\"));             \n"
+"          g_warning(\"%s\", _(\"could not create a new Jasper stream\"));     \n"
 "          cleanup(operation);                                                 \n"
 "          return;                                                             \n"
 "        }                                                                     \n"
@@ -266,7 +266,7 @@ static const char* op_c_source =
 "      stream = gegl_gio_open_input_stream(o->uri, o->path, &p->file, &error); \n"
 "      if (stream == NULL)                                                     \n"
 "        {                                                                     \n"
-"          g_warning(error->message);                                          \n"
+"          g_warning(\"%s\", error->message);                                  \n"
 "          g_error_free(error);                                                \n"
 "          cleanup(operation);                                                 \n"
 "          return;                                                             \n"
@@ -291,7 +291,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "      if (!query_jp2(operation, jasper))                                      \n"
 "        {                                                                     \n"
-"          g_warning(_(\"could not query JPEG 2000 file\"));                   \n"
+"          g_warning(\"%s\", _(\"could not query JPEG 2000 file\"));           \n"
 "          cleanup(operation);                                                 \n"
 "          return;                                                             \n"
 "        }                                                                     \n"
@@ -347,7 +347,7 @@ static const char* op_c_source =
 "                                                                              \n"
 "      if ((components[0] < 0) || (components[1] < 0) || (components[2] < 0))  \n"
 "        {                                                                     \n"
-"          g_warning (_(\"One or more of R, G, B components are missing\"));   \n"
+"          g_warning (\"%s\",_(\"One or more of R, G, B components are missing\"));\n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
@@ -355,7 +355,7 @@ static const char* op_c_source =
 "          jas_image_cmptsgnd (p->image, components[1]) ||                     \n"
 "          jas_image_cmptsgnd (p->image, components[2]))                       \n"
 "        {                                                                     \n"
-"          g_warning (_(\"One or more of R, G, B components have signed data\"));\n"
+"          g_warning (\"%s\",_(\"One or more of R, G, B components have signed data\"));\n"
 "          break;                                                              \n"
 "        }                                                                     \n"
 "                                                                              \n"
@@ -533,8 +533,14 @@ static const char* op_c_source =
 "    \"description\", _(\"JPEG 2000 image loader using jasper.\"),             \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".jp2\", \"gegl:jp2-load\");       \n"
-"  gegl_extension_handler_register_loader (\".jpx\", \"gegl:jp2-load\");       \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/jp2\", \"gegl:jp2-load\");                                        \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".jp2\", \"gegl:jp2-load\");                                             \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".jpf\", \"gegl:jp2-load\");                                             \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".jpx\", \"gegl:jp2-load\");                                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
