@@ -371,8 +371,12 @@ static const char* op_c_source =
 "/*  static gboolean done=FALSE;                                               \n"
 "    if (done)                                                                 \n"
 "      return; */                                                              \n"
-"  gegl_extension_handler_register_loader (\".jpg\", \"gegl:jpg-load\");       \n"
-"  gegl_extension_handler_register_loader (\".jpeg\", \"gegl:jpg-load\");      \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/jpeg\", \"gegl:jpg-load\");                                       \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".jpeg\", \"gegl:jpg-load\");                                            \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".jpg\", \"gegl:jpg-load\");                                             \n"
 "/*  done = TRUE; */                                                           \n"
 "}                                                                             \n"
 "#endif                                                                        \n"
