@@ -199,7 +199,10 @@ static const char* op_c_source =
 "    _(\"JPEG image saver, using libjpeg\"),                                   \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_saver (\".jpg\", \"gegl:jpg-save\");        \n"
+"  gegl_operation_handlers_register_saver (                                    \n"
+"    \".jpeg\", \"gegl:jpg-save\");                                            \n"
+"  gegl_operation_handlers_register_saver (                                    \n"
+"    \".jpg\", \"gegl:jpg-save\");                                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
