@@ -20,44 +20,41 @@ static const char* op_c_source =
 "#include \"config.h\"                                                         \n"
 "#include <glib/gi18n-lib.h>                                                   \n"
 "                                                                              \n"
-"#ifdef GEGL_CHANT_PROPERTIES                                                  \n"
-"gegl_chant_pointer (model,       _(\"Model\"),                                \n"
-"                    _(\"Model - basic element we operate on\"))               \n"
+"#ifdef GEGL_PROPERTIES                                                        \n"
+"property_pointer (model, _(\"Model\"), NULL)                                  \n"
+"description (_(\"Model - basic element we operate on\"))                      \n"
 "                                                                              \n"
-"gegl_chant_int     (square_size, _(\"Square Size\"),                          \n"
-"                    5,  1000,  20,                                            \n"
-"                    _(\"Size of an edge of square the mesh consists of\"))    \n"
+"property_int  (square_size, _(\"Square Size\"), 20)                           \n"
+"value_range (5, 1000)                                                         \n"
+"description(_(\"Size of an edge of square the mesh consists of\"))            \n"
 "                                                                              \n"
-"gegl_chant_int     (rigidity,    _(\"Rigidity\"),                             \n"
-"                    0, 10000, 100,                                            \n"
-"                    _(\"The number of deformation iterations\"))              \n"
+"property_int (rigidity,    _(\"Rigidity\"), 100)                              \n"
+"value_range (0, 10000)                                                        \n"
+"description(_(\"The number of deformation iterations\"))                      \n"
 "                                                                              \n"
-"gegl_chant_boolean (asap_deformation, _(\"ASAP Deformation\"),                \n"
-"                    FALSE,                                                    \n"
-"                    _(\"ASAP deformation is performed when TRUE, ARAP deformation otherwise\"))\n"
+"property_boolean (asap_deformation, _(\"ASAP Deformation\"), FALSE)           \n"
+"description(_(\"ASAP deformation is performed when TRUE, ARAP deformation otherwise\"))\n"
 "                                                                              \n"
-"gegl_chant_boolean (mls_weights, _(\"MLS Weights\"),                          \n"
-"                    FALSE,                                                    \n"
-"                    _(\"Use MLS weights\"))                                   \n"
+"property_boolean (mls_weights, _(\"MLS Weights\"), FALSE)                     \n"
+"description(_(\"Use MLS weights\"))                                           \n"
 "                                                                              \n"
-"gegl_chant_double  (mls_weights_alpha, _(\"MLS Weights Alpha\"),              \n"
-"                    0.1, 2.0, 1.0,                                            \n"
-"                    _(\"Alpha parameter of MLS weights\"))                    \n"
+"property_double  (mls_weights_alpha, _(\"MLS Weights Alpha\"), 1.0)           \n"
+"value_range (0.1, 2.0)                                                        \n"
+"description(_(\"Alpha parameter of MLS weights\"))                            \n"
 "                                                                              \n"
-"gegl_chant_boolean (preserve_model, _(\"Preserve Model\"),                    \n"
-"                    FALSE,                                                    \n"
-"                    _(\"When TRUE the model will not be freed\"))             \n"
+"property_boolean (preserve_model, _(\"Preserve Model\"), FALSE)               \n"
+"description(_(\"When TRUE the model will not be freed\"))                     \n"
 "                                                                              \n"
-"gegl_chant_enum    (sampler_type, _(\"Sampler\"),                             \n"
+"property_enum (sampler_type, _(\"Sampler\"),                                  \n"
 "                    GeglSamplerType, gegl_sampler_type,                       \n"
-"                    GEGL_SAMPLER_CUBIC,                                       \n"
-"                    _(\"Sampler used internally\"))                           \n"
+"                    GEGL_SAMPLER_CUBIC)                                       \n"
+"description(_(\"Sampler used internally\"))                                   \n"
 "#else                                                                         \n"
 "                                                                              \n"
-"#define GEGL_CHANT_TYPE_FILTER                                                \n"
-"#define GEGL_CHANT_C_FILE       \"npd.c\"                                     \n"
+"#define GEGL_OP_FILTER                                                        \n"
+"#define GEGL_OP_C_SOURCE npd.c                                                \n"
 "                                                                              \n"
-"#include \"gegl-chant.h\"                                                     \n"
+"#include \"gegl-op.h\"                                                        \n"
 "#include <stdio.h>                                                            \n"
 "#include <math.h>                                                             \n"
 "#include <npd/npd.h>                                                          \n"
@@ -77,14 +74,14 @@ static const char* op_c_source =
 "static void                                                                   \n"
 "prepare (GeglOperation *operation)                                            \n"
 "{                                                                             \n"
-"  GeglChantO    *o = GEGL_CHANT_PROPERTIES (operation);                       \n"
+"  GeglProperties *o = GEGL_PROPERTIES (operation);                            \n"
 "  NPDProperties *props;                                                       \n"
-"  if (o->chant_data == NULL)                                                  \n"
+"  if (o->user_data == NULL)                                                   \n"
 "    {                                                                         \n"
 "      props = g_new (NPDProperties, 1);                                       \n"
 "      props->first_run      = TRUE;                                           \n"
 "      props->model          = o->model;                                       \n"
-"      o->chant_data         = props;                                          \n"
+"      o->user_data         = props;                                           \n"
 "    }                                                                         \n"
 "                                                                              \n"
 "  gegl_operation_set_format (operation, \"output\", babl_format (\"RGBA float\"));\n"
@@ -148,9 +145,9 @@ static const char* op_c_source =
 "         const GeglRectangle *roi,                                            \n"
 "         gint                 level)                                          \n"
 "{                                                                             \n"
-"  GeglChantO    *o          = GEGL_CHANT_PROPERTIES (operation);              \n"
+"  GeglProperties*o          = GEGL_PROPERTIES (operation);                    \n"
 "  const Babl    *format_f   = babl_format (\"RGBA float\");                   \n"
-"  NPDProperties *props      = o->chant_data;                                  \n"
+"  NPDProperties *props      = o->user_data;                                   \n"
 "  NPDModel      *model      = props->model;                                   \n"
 "  gboolean       have_model = model != NULL;                                  \n"
 "  NPDDisplay    *display    = NULL;                                           \n"
@@ -218,11 +215,11 @@ static const char* op_c_source =
 "static void                                                                   \n"
 "finalize (GObject *object)                                                    \n"
 "{                                                                             \n"
-"  GeglChantO *o = GEGL_CHANT_PROPERTIES (object);                             \n"
+"  GeglProperties *o = GEGL_PROPERTIES (object);                               \n"
 "                                                                              \n"
-"  if (o->chant_data)                                                          \n"
+"  if (o->user_data)                                                           \n"
 "    {                                                                         \n"
-"      NPDProperties *props   = o->chant_data;                                 \n"
+"      NPDProperties *props   = o->user_data;                                  \n"
 "      NPDModel      *model   = props->model;                                  \n"
 "      NPDDisplay    *display = model->display;                                \n"
 "                                                                              \n"
@@ -234,14 +231,14 @@ static const char* op_c_source =
 "          g_free (model);                                                     \n"
 "        }                                                                     \n"
 "                                                                              \n"
-"      o->chant_data = NULL;                                                   \n"
+"      o->user_data = NULL;                                                    \n"
 "    }                                                                         \n"
 "                                                                              \n"
-"  G_OBJECT_CLASS (gegl_chant_parent_class)->finalize (object);                \n"
+"  G_OBJECT_CLASS (gegl_op_parent_class)->finalize (object);                   \n"
 "}                                                                             \n"
 "                                                                              \n"
 "static void                                                                   \n"
-"gegl_chant_class_init (GeglChantClass *klass)                                 \n"
+"gegl_op_class_init (GeglOpClass *klass)                                       \n"
 "{                                                                             \n"
 "  GeglOperationClass       *operation_class;                                  \n"
 "  GeglOperationFilterClass *filter_class;                                     \n"
