@@ -502,7 +502,10 @@ gegl_op_class_init (GeglOpClass *klass)
 /*  static gboolean done=FALSE;
     if (done)
       return; */
-  gegl_extension_handler_register_loader (".png", "gegl:png-load");
+  gegl_operation_handlers_register_loader (
+    "image/png", "gegl:png-load");
+  gegl_operation_handlers_register_loader (
+    ".png", "gegl:png-load");
 /*  done = TRUE; */
 }
 
