@@ -503,7 +503,10 @@ static const char* op_c_source =
 "/*  static gboolean done=FALSE;                                               \n"
 "    if (done)                                                                 \n"
 "      return; */                                                              \n"
-"  gegl_extension_handler_register_loader (\".png\", \"gegl:png-load\");       \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/png\", \"gegl:png-load\");                                        \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".png\", \"gegl:png-load\");                                             \n"
 "/*  done = TRUE; */                                                           \n"
 "}                                                                             \n"
 "                                                                              \n"
