@@ -232,7 +232,8 @@ static const char* op_c_source =
 "        _(\"PNG image saver, using libpng\"),                                 \n"
 "        NULL);                                                                \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_saver (\".png\", \"gegl:png-save\");        \n"
+"  gegl_operation_handlers_register_saver (                                    \n"
+"    \".png\", \"gegl:png-save\");                                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
