@@ -384,9 +384,20 @@ static const char* op_c_source =
 "    \"description\",  _(\"PPM image loader.\"),                               \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".ppm\", \"gegl:ppm-load\");       \n"
-"  gegl_extension_handler_register_loader (\".pgm\", \"gegl:ppm-load\");       \n"
-"  gegl_extension_handler_register_loader (\".pnm\", \"gegl:ppm-load\");       \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-portable-pixmap\", \"gegl:ppm-load\");                          \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".ppm\", \"gegl:ppm-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-portable-graymap:\", \"gegl:ppm-load\");                        \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".pgm\", \"gegl:ppm-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-portable-anymap\", \"gegl:ppm-load\");                          \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".pnm\", \"gegl:ppm-load\");                                             \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
