@@ -245,15 +245,45 @@ static const char* op_c_source =
 "  if (done)                                                                   \n"
 "    return;                                                                   \n"
 "                                                                              \n"
-"  /* query libopenraw instead. need a new API */                              \n"
-"  gegl_extension_handler_register_loader (\".pef\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".nef\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".raf\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".orf\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".erf\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".mrw\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".crw\", \"gegl:raw-load\");       \n"
-"  gegl_extension_handler_register_loader (\".cr2\", \"gegl:raw-load\");       \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-pentax-pef\", \"gegl:raw-load\");                               \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".pef\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-nikon-nef\", \"gegl:raw-load\");                                \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".nef\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-fuji-raf\", \"gegl:raw-load\");                                 \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".raf\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-olympus-orf\", \"gegl:raw-load\");                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".orf\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-epson-erf\", \"gegl:raw-load\");                                \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".erf\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-minolta-mrw\", \"gegl:raw-load\");                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".mrw\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-canon-crw\", \"gegl:raw-load\");                                \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".crw\", \"gegl:raw-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/x-canon-cr2\", \"gegl:raw-load\");                                \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".cr2\", \"gegl:raw-load\");                                             \n"
 "                                                                              \n"
 "  done = TRUE;                                                                \n"
 "}                                                                             \n"
