@@ -138,8 +138,12 @@ static const char* op_c_source =
 "    \"description\" , _(\"RGBE image loader (Radiance HDR format).\"),        \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".hdr\", \"gegl:rgbe-load\");      \n"
-"  gegl_extension_handler_register_loader (\".pic\", \"gegl:rgbe-load\");      \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/vnd.radiance\", \"gegl:rgbe-load\");                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".hdr\", \"gegl:rgbe-load\");                                            \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".pic\", \"gegl:rgbe-load\");                                            \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
