@@ -164,7 +164,7 @@ prepare (GeglOperation *operation)
       stream = gegl_gio_open_input_stream (o->uri, o->path, &p->file, &error);
       if (stream == NULL)
         {
-          g_warning (error->message);
+          g_warning ("%s", error->message);
           g_error_free (error);
           cleanup (operation);
           return;
@@ -175,7 +175,7 @@ prepare (GeglOperation *operation)
                                                     NULL, &error);
       if (p->handle == NULL)
         {
-          g_warning (error->message);
+          g_warning ("%s", error->message);
           g_error_free (error);
           cleanup (operation);
           return;
@@ -294,8 +294,15 @@ gegl_op_class_init (GeglOpClass *klass)
     "description" , _("Load an SVG file using librsvg"),
     NULL);
 
-  gegl_extension_handler_register_loader (".svg", "gegl:svg-load");
-  gegl_extension_handler_register_loader (".svgz", "gegl:svg-load");
+  gegl_operation_handlers_register_loader (
+    "image/svg+xml", "gegl:svg-load");
+  gegl_operation_handlers_register_loader (
+    ".svg", "gegl:svg-load");
+
+  gegl_operation_handlers_register_loader (
+    "image/svg+xml-compressed", "gegl:svg-load");
+  gegl_operation_handlers_register_loader (
+    ".svgz", "gegl:svg-load");
 }
 
 #endif
