@@ -165,7 +165,7 @@ static const char* op_c_source =
 "      stream = gegl_gio_open_input_stream (o->uri, o->path, &p->file, &error);\n"
 "      if (stream == NULL)                                                     \n"
 "        {                                                                     \n"
-"          g_warning (error->message);                                         \n"
+"          g_warning (\"%s\", error->message);                                 \n"
 "          g_error_free (error);                                               \n"
 "          cleanup (operation);                                                \n"
 "          return;                                                             \n"
@@ -176,7 +176,7 @@ static const char* op_c_source =
 "                                                    NULL, &error);            \n"
 "      if (p->handle == NULL)                                                  \n"
 "        {                                                                     \n"
-"          g_warning (error->message);                                         \n"
+"          g_warning (\"%s\", error->message);                                 \n"
 "          g_error_free (error);                                               \n"
 "          cleanup (operation);                                                \n"
 "          return;                                                             \n"
@@ -295,8 +295,15 @@ static const char* op_c_source =
 "    \"description\" , _(\"Load an SVG file using librsvg\"),                  \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".svg\", \"gegl:svg-load\");       \n"
-"  gegl_extension_handler_register_loader (\".svgz\", \"gegl:svg-load\");      \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/svg+xml\", \"gegl:svg-load\");                                    \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".svg\", \"gegl:svg-load\");                                             \n"
+"                                                                              \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/svg+xml-compressed\", \"gegl:svg-load\");                         \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".svgz\", \"gegl:svg-load\");                                            \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
