@@ -95,7 +95,7 @@ static const char* op_c_source =
 "  gchar *message;                                                             \n"
 "                                                                              \n"
 "  g_vasprintf(&message, format, arguments);                                   \n"
-"  g_warning(message);                                                         \n"
+"  g_warning(\"%s\", message);                                                 \n"
 "                                                                              \n"
 "  g_free(message);                                                            \n"
 "}                                                                             \n"
@@ -108,7 +108,7 @@ static const char* op_c_source =
 "  gchar *message;                                                             \n"
 "                                                                              \n"
 "  g_vasprintf(&message, format, arguments);                                   \n"
-"  g_message(message);                                                         \n"
+"  g_message(\"%s\", message);                                                 \n"
 "                                                                              \n"
 "  g_free(message);                                                            \n"
 "}                                                                             \n"
@@ -145,7 +145,7 @@ static const char* op_c_source =
 "                                      NULL, &error);                          \n"
 "      if (written < 0)                                                        \n"
 "        {                                                                     \n"
-"          g_warning(error->message);                                          \n"
+"          g_warning(\"%s\", error->message);                                  \n"
 "          g_error_free(error);                                                \n"
 "        }                                                                     \n"
 "    }                                                                         \n"
@@ -193,7 +193,7 @@ static const char* op_c_source =
 "        position = g_seekable_tell(G_SEEKABLE(p->stream));                    \n"
 "      else                                                                    \n"
 "        {                                                                     \n"
-"          g_warning(error->message);                                          \n"
+"          g_warning(\"%s\", error->message);                                  \n"
 "          g_error_free(error);                                                \n"
 "        }                                                                     \n"
 "    }                                                                         \n"
@@ -244,7 +244,7 @@ static const char* op_c_source =
 "                                          NULL, &error);                      \n"
 "          if (written < 0)                                                    \n"
 "            {                                                                 \n"
-"                  g_warning(error->message);                                  \n"
+"                  g_warning(\"%s\", error->message);                          \n"
 "                  g_error_free(error);                                        \n"
 "                  break;                                                      \n"
 "            }                                                                 \n"
@@ -257,7 +257,7 @@ static const char* op_c_source =
 "                                 NULL, &error);                               \n"
 "  if (!closed)                                                                \n"
 "    {                                                                         \n"
-"      g_warning(error->message);                                              \n"
+"      g_warning(\"%s\", error->message);                                      \n"
 "      g_error_free(error);                                                    \n"
 "    }                                                                         \n"
 "                                                                              \n"
@@ -294,7 +294,7 @@ static const char* op_c_source =
 "                               NULL, &error);                                 \n"
 "      if (info == NULL)                                                       \n"
 "        {                                                                     \n"
-"          g_warning(error->message);                                          \n"
+"          g_warning(\"%s\", error->message);                                  \n"
 "          g_error_free(error);                                                \n"
 "        }                                                                     \n"
 "      else                                                                    \n"
@@ -568,7 +568,7 @@ static const char* op_c_source =
 "  if (p->stream == NULL)                                                      \n"
 "    {                                                                         \n"
 "      status = FALSE;                                                         \n"
-"      g_warning(error->message);                                              \n"
+"      g_warning(\"%s\", error->message);                                      \n"
 "      goto cleanup;                                                           \n"
 "    }                                                                         \n"
 "                                                                              \n"
@@ -624,8 +624,10 @@ static const char* op_c_source =
 "    \"description\", _(\"TIFF image saver using libtiff\"),                   \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_saver(\".tiff\", \"gegl:tiff-save\");       \n"
-"  gegl_extension_handler_register_saver(\".tif\", \"gegl:tiff-save\");        \n"
+"  gegl_operation_handlers_register_saver(                                     \n"
+"    \".tiff\", \"gegl:tiff-save\");                                           \n"
+"  gegl_operation_handlers_register_saver(                                     \n"
+"    \".tif\", \"gegl:tiff-save\");                                            \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
