@@ -101,7 +101,7 @@ static const char* op_c_source =
 "                                     NULL, &error);                           \n"
 "  if (!success || error != NULL)                                              \n"
 "    {                                                                         \n"
-"      g_warning (error->message);                                             \n"
+"      g_warning (\"%s\", error->message);                                     \n"
 "      g_error_free (error);                                                   \n"
 "      return -1;                                                              \n"
 "    }                                                                         \n"
@@ -131,7 +131,7 @@ static const char* op_c_source =
 "                                         NULL, &error);                       \n"
 "      if (!success || error != NULL)                                          \n"
 "        {                                                                     \n"
-"          g_warning (error->message);                                         \n"
+"          g_warning (\"%s\", error->message);                                 \n"
 "          g_error_free (error);                                               \n"
 "          return -1;                                                          \n"
 "        }                                                                     \n"
@@ -209,7 +209,7 @@ static const char* op_c_source =
 "      p->stream = gegl_gio_open_input_stream (o->uri, o->path, &p->file, &error);\n"
 "      if (p->stream == NULL)                                                  \n"
 "        {                                                                     \n"
-"          g_warning (error->message);                                         \n"
+"          g_warning (\"%s\", error->message);                                 \n"
 "          g_error_free (error);                                               \n"
 "          cleanup (operation);                                                \n"
 "          return;                                                             \n"
@@ -349,7 +349,10 @@ static const char* op_c_source =
 "    \"description\" , _(\"WebP image loader.\"),                              \n"
 "    NULL);                                                                    \n"
 "                                                                              \n"
-"  gegl_extension_handler_register_loader (\".webp\", \"gegl:webp-load\");     \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \"image/webp\", \"gegl:webp-load\");                                      \n"
+"  gegl_operation_handlers_register_loader (                                   \n"
+"    \".webp\", \"gegl:webp-load\");                                           \n"
 "}                                                                             \n"
 "                                                                              \n"
 "#endif                                                                        \n"
