@@ -1,7 +1,6 @@
 #ifndef __OP_TRANSFORM_H__
 #define __OP_TRANSFORM_H__
 
-#include "gegl-buffer-private.h"
 #include <gegl-matrix.h>
 
 G_BEGIN_DECLS
@@ -20,9 +19,7 @@ struct _OpTransform
   GeglOperationFilter parent_instance;
   gdouble             origin_x;
   gdouble             origin_y;
-  gchar              *filter;
-  gboolean            hard_edges;
-  gint                lanczos_width;
+  GeglSamplerType     sampler;
 };
 
 typedef struct _OpTransformClass OpTransformClass;
